@@ -103,6 +103,7 @@ pub struct AquaFile {
 #[serde(rename_all = "lowercase")]
 #[strum(serialize_all = "lowercase")]
 pub enum AquaChecksumAlgorithm {
+    Blake3,
     Sha1,
     Sha256,
     Sha512,
@@ -460,7 +461,7 @@ impl AquaPackage {
         expr.run(program, &self.expr_ctx(v)).map_err(|e| eyre!(e))
     }
 
-    fn expr_parser(&self, v: &str) -> expr::Environment {
+    fn expr_parser(&self, v: &str) -> expr::Environment<'_> {
         let prefix = Regex::new(r"^[^0-9.]+").unwrap();
         let ver = versions::Versioning::new(prefix.replace(v, ""));
         let mut env = expr::Environment::new();
