@@ -98,15 +98,63 @@ impl BackendArg {
         // Ok(backend.clone())
         if let Some(backend) = backend::get(self) {
             Ok(backend)
+        } else if let Some((plugin_name, tool_name)) = self.short.split_once(':') {
+            // Check if the plugin exists first
+            if let Some(plugin_type) = install_state::get_plugin_type(plugin_name) {
+                // Plugin exists, but the backend couldn't be created
+                // This could be due to the tool not being available or plugin not properly installed
+                match plugin_type {
+                    PluginType::Asdf => {
+                        bail!(
+                            "asdf plugin '{plugin_name}' exists but '{tool_name}' is not available or the plugin is not properly installed"
+                        );
+                    }
+                    PluginType::Vfox => {
+                        bail!(
+                            "vfox plugin '{plugin_name}' exists but '{tool_name}' is not available or the plugin is not properly installed"
+                        );
+                    }
+                    PluginType::VfoxBackend => {
+                        bail!(
+                            "vfox-backend plugin '{plugin_name}' exists but '{tool_name}' is not available or the plugin is not properly installed"
+                        );
+                    }
+                }
+            } else {
+                // Plugin doesn't exist
+                bail!("{plugin_name} is not a valid plugin name");
+            }
         } else {
             bail!("{self} not found in mise tool registry");
         }
     }
 
     pub fn backend_type(&self) -> BackendType {
-        if let Ok(Some(backend_type)) = install_state::backend_type(&self.short) {
-            return backend_type;
+        // Check if this is a valid backend:tool format first
+        if let Some((backend_prefix, _tool_name)) = self.short.split_once(':') {
+            if let Ok(backend_type) = backend_prefix.parse::<BackendType>() {
+                return backend_type;
+            }
         }
+
+        // Then check if this is a vfox plugin:tool format
+        if let Some((plugin_name, _tool_name)) = self.short.split_once(':') {
+            if let Some(plugin_type) = install_state::get_plugin_type(plugin_name) {
+                return match plugin_type {
+                    PluginType::Vfox => BackendType::Vfox,
+                    PluginType::VfoxBackend => BackendType::VfoxBackend(plugin_name.to_string()),
+                    PluginType::Asdf => BackendType::Asdf,
+                };
+            }
+        }
+
+        // Only check install state for non-plugin:tool format entries
+        if !self.short.contains(':') {
+            if let Ok(Some(backend_type)) = install_state::backend_type(&self.short) {
+                return backend_type;
+            }
+        }
+
         let full = self.full();
         let backend = full.split(':').next().unwrap();
         if let Ok(backend_type) = backend.parse() {
@@ -155,10 +203,31 @@ impl BackendArg {
             full.clone()
         } else if let Some(full) = install_state::get_tool_full(short) {
             full
+        } else if let Some((plugin_name, _tool_name)) = short.split_once(':') {
+            // Check if this is a plugin:tool format
+            if let Some(pt) = install_state::get_plugin_type(plugin_name) {
+                match pt {
+                    PluginType::Asdf => {
+                        // For asdf plugins, plugin:tool format is invalid
+                        // Return just the plugin name since asdf doesn't support plugin:tool structure
+                        plugin_name.to_string()
+                    }
+                    // For vfox plugins, when already in plugin:tool format, return as-is
+                    // because the plugin itself is the backend specification
+                    PluginType::Vfox => short.to_string(),
+                    PluginType::VfoxBackend => short.to_string(),
+                }
+            } else if plugin_name.starts_with("asdf-") {
+                // Handle asdf plugin:tool format even if not installed
+                plugin_name.to_string()
+            } else {
+                short.to_string()
+            }
         } else if let Some(pt) = install_state::get_plugin_type(short) {
             match pt {
                 PluginType::Asdf => format!("asdf:{short}"),
                 PluginType::Vfox => format!("vfox:{short}"),
+                PluginType::VfoxBackend => short.to_string(),
             }
         } else if let Some(full) = REGISTRY
             .get(short)
@@ -270,7 +339,7 @@ impl Eq for BackendArg {}
 
 impl PartialOrd for BackendArg {
     fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
-        Some(self.short.cmp(&other.short))
+        Some(self.cmp(other))
     }
 }
 
@@ -343,4 +412,39 @@ mod tests {
         );
         t("vfox:version-fox/nodejs", "vfox-version-fox-nodejs");
     }
+
+    #[tokio::test]
+    async fn test_backend_arg_bug_fixes() {
+        let _config = Config::get().await.unwrap();
+
+        // Test that asdf plugins in plugin:tool format return just the plugin name
+        // (asdf doesn't support plugin:tool structure)
+        let fa: BackendArg = "asdf-plugin:tool".into();
+        assert_str_eq!("asdf-plugin", fa.full());
+
+        // Test that vfox plugins in plugin:tool format return as-is
+        let fa: BackendArg = "vfox-plugin:tool".into();
+        assert_str_eq!("vfox-plugin:tool", fa.full());
+    }
+
+    #[tokio::test]
+    async fn test_backend_arg_improved_error_messages() {
+        let _config = Config::get().await.unwrap();
+
+        // Test that when a plugin exists but the tool is not available,
+        // we get a more specific error message instead of "not a valid backend name"
+        let fa: BackendArg = "nonexistent-plugin:some-tool".into();
+        let result = fa.backend();
+        assert!(result.is_err());
+        let error_msg = result.unwrap_err().to_string();
+        assert!(
+            error_msg.contains("is not a valid plugin name"),
+            "Expected error to mention invalid plugin name, got: {error_msg}"
+        );
+
+        // Note: We can't easily test the case where a plugin exists but the tool doesn't
+        // because that would require setting up actual plugins in the test environment.
+        // The logic has been improved to check plugin existence first and provide
+        // more specific error messages based on the plugin type.
+    }
 }
