@@ -13,7 +13,6 @@ use crate::config::{Config, Settings};
 use crate::file::{TarFormat, TarOptions};
 use crate::http::{HTTP, HTTP_FETCH};
 use crate::install_context::InstallContext;
-use crate::plugins::VERSION_REGEX;
 use crate::toolset::{ToolVersion, Toolset};
 use crate::ui::progress_report::SingleReport;
 use crate::{file, plugins};
@@ -27,6 +26,13 @@ use std::sync::LazyLock as Lazy;
 use versions::Versioning;
 use xx::regex;
 
+static VERSION_REGEX: Lazy<regex::Regex> = Lazy::new(|| {
+    Regex::new(
+        r"(?i)(^Available versions:|-src|-dev|-latest|-stm|[-\\.]rc|-milestone|-alpha|-beta|[-\\.]pre|-next|snapshot|SNAPSHOT|master)"
+    )
+        .unwrap()
+});
+
 #[derive(Debug)]
 pub struct JavaPlugin {
     ba: Arc<BackendArg>,
@@ -38,20 +44,16 @@ impl JavaPlugin {
     pub fn new() -> Self {
         let settings = Settings::get();
         let ba = Arc::new(plugins::core::new_backend_arg("java"));
-        let java_metadata_ga_cache_filename =
-            format!("java_metadata_ga_{}_{}.msgpack.z", os(), arch(&settings));
-        let java_metadata_ea_cache_filename =
-            format!("java_metadata_ea_{}_{}.msgpack.z", os(), arch(&settings));
         Self {
             java_metadata_ea_cache: CacheManagerBuilder::new(
-                ba.cache_path.join(java_metadata_ea_cache_filename),
+                ba.cache_path.join("java_metadata_ea.msgpack.z"),
             )
-            .with_fresh_duration(Settings::get().fetch_remote_versions_cache())
+            .with_fresh_duration(settings.fetch_remote_versions_cache())
             .build(),
             java_metadata_ga_cache: CacheManagerBuilder::new(
-                ba.cache_path.join(java_metadata_ga_cache_filename),
+                ba.cache_path.join("java_metadata_ga.msgpack.z"),
             )
-            .with_fresh_duration(Settings::get().fetch_remote_versions_cache())
+            .with_fresh_duration(settings.fetch_remote_versions_cache())
             .build(),
             ba,
         }
